==> monthofswords-common-1.21.1-sources.jar: com/samsthenerd/monthofswords/items/FloralSwordItem.java <==
package com.samsthenerd.monthofswords.items;

import java.util.function.UnaryOperator;
import net.minecraft.class_124;
import net.minecraft.class_1297;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1829;
import net.minecraft.class_1856;
import net.minecraft.class_1937;
import net.minecraft.class_1944;
import net.minecraft.class_2583;
import net.minecraft.class_3218;
import net.minecraft.class_3481;
import net.minecraft.class_5819;

public class FloralSwordItem extends SwordtemberItem {

    private static class_5819 random = class_5819.method_43053();

    public static final ClassyToolMaterial FLORAL_MATERIAL = new ClassyToolMaterial(150, 8f, 1f,
            class_3481.field_49930, 18, () -> class_1856.field_9017);

    public FloralSwordItem(class_1792.class_1793 itemSettings){
        super(FLORAL_MATERIAL, itemSettings.method_57348(class_1829.method_57394(FLORAL_MATERIAL, 3, -2.4f)));
    }

    @Override
    public UnaryOperator<class_2583> getSwordTooltipStyleModifier(){
        return (style) -> style.method_10977(class_124.field_1060);
    }

    @Override
    public void method_7888(class_1799 stack, class_1937 world, class_1297 entity, int slot, boolean selected) {
        int skyLight = world.method_22336().method_15562(class_1944.field_9284).method_15543(entity.method_24515());
        boolean probSaysYes = random.method_43048(100) < 5; // once a second?
        if(world instanceof class_3218 sWorld && stack.method_7919() > 0 && slot >= 0 && slot < 9
                && skyLight > 7 && sWorld.method_8530() &&  probSaysYes){
            stack.method_7974(Math.max(stack.method_7919()-1, 0));
        }
    }
}

==> monthofswords-common-1.30.0-47-sources.jar: com/samsthenerd/monthofswords/items/FloralSwordItem.java <==
package com.samsthenerd.monthofswords.items;

import java.util.function.UnaryOperator;
import net.minecraft.class_124;
import net.minecraft.class_1297;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1829;
import net.minecraft.class_1856;
import net.minecraft.class_1937;
import net.minecraft.class_1944;
import net.minecraft.class_2583;
import net.minecraft.class_3218;
import net.minecraft.class_3481;
import net.minecraft.class_5819;

public class FloralSwordItem extends SwordtemberItem {

    private static class_5819 random = class_5819.method_43053();

    public static final ClassyToolMaterial FLORAL_MATERIAL = new ClassyToolMaterial(150, 8f, 1f,
            class_3481.field_49930, 18, () -> class_1856.field_9017);

    public FloralSwordItem(class_1792.class_1793 itemSettings){
        super(FLORAL_MATERIAL, itemSettings.method_57348(class_1829.method_57394(FLORAL_MATERIAL, 3, -2.4f)));
    }

    @Override
    public UnaryOperator<class_2583> getSwordTooltipStyleModifier(){
        return (style) -> style.method_10977(class_124.field_1060);
    }

    @Override
    public void method_7888(class_1799 stack, class_1937 world, class_1297 entity, int slot, boolean selected) {
        int skyLight = world.method_22336().method_15562(class_1944.field_9284).method_15543(entity.method_24515());
//        boolean probSaysYes = random.nextInt(100) < 5; // once a second?
        boolean probSaysYes = entity.field_6012 % 100 == 0; // 2 damage a second?
        if(world instanceof class_3218 sWorld && stack.method_7919() > 0 && slot >= 0 && slot < 9
                && skyLight > 7 && sWorld.method_8530() &&  probSaysYes){
            stack.method_7974(Math.max(stack.method_7919()-10, 0));
        }
    }
}
